@@ -4,6 +4,7 @@ Main module containing functions.
 from Bio import SeqIO, Entrez
 from os import path
 from subprocess import Popen, PIPE, getoutput
+from tqdm import tqdm
 import pandas as pd
 
 
@@ -382,7 +383,7 @@ def fetch_ncbi_information(
 
     # Fetching data from NCBI
     print("Fetching NCBI data for {} accessions [...]".format(len(accessions)))
-    for acc in accessions:
+    for acc in tqdm(accessions):
         handles[acc] = parse_handle(acc)
 
     # Parsing texts
@@ -435,7 +436,9 @@ def fetch_ncbi_information(
             )
 
     # Sorting columns for output
-    new_cols = list(asv_table_with_neighbors_and_ncbi.columns[:11])
+    new_cols = [
+        i for i in asv_table_with_neighbors_and_ncbi.columns if "cultured" not in i
+    ]
     culture_cols = [
         i for i in asv_table_with_neighbors_and_ncbi.columns if "cultured" in i
     ]
